@@ -5,7 +5,7 @@ from PySense import PySenseException
 
 
 class RestConnector:
-    
+
     def __init__(self, host, username, password, debug, verify):
         self._host = format_host(host)
         self.debug = debug
@@ -14,24 +14,22 @@ class RestConnector:
         resp = requests.post('{}/api/v1/authentication/login'.format(self._host), data=data)
         parse_response(resp)
         self._token = {'authorization':  "Bearer " + resp.json()['access_token']}
-        
+
     def rest_call(self, action_type, url, *, data=None, json_payload=None, query_params=None, raw=False):
-        """Run an arbitrary rest command against your Sisense instance and returns the JSON response    
-    
+        """Run an arbitrary rest command against your Sisense instance and returns the JSON response
+
         Args:
-            - action_type: REST request type  
-            - url: url to hit, example api/v1/app_database/encrypt_database_password or api/branding  
-              
-        Optional:
-            - data: The data portion of the payload  
-            - json_payload: The json portion of the payload  
-            - query_params: a dictionary of query values to be added to the end of the url  
-            - raw: True if raw content response wanted  
-        
+            action_type: REST request type
+            url: url to hit, example api/v1/app_database/encrypt_database_password or api/branding
+            data: (optional) The data portion of the payload
+            json_payload: (optional) The json portion of the payload
+            query_params: (optional) A dictionary of query values to be added to the end of the url
+            raw: (optional) True if raw content response wanted
+
         Returns:
-            Returns the json content blob. If raw is set to true, returns the raw bytes of the content. 
+            Returns the json content blob. If raw is set to true, returns the raw bytes of the content.
         """
-        
+
         action_type = action_type.lower()
         if query_params is not None:
             query_string = build_query_string(query_params)
@@ -45,7 +43,7 @@ class RestConnector:
                 print('Data: {}'.format(data))
             if json_payload is not None:
                 print('JSON: {}'.format(json_payload))
-        response = requests.request(action_type, full_url, 
+        response = requests.request(action_type, full_url,
                                     headers=self._token, data=data, json=json_payload, verify=self.verify)
         parse_response(response)
         if len(response.content) == 0:
@@ -57,7 +55,7 @@ class RestConnector:
                 return response.json()
             except ValueError as e:
                 return response.content
-            
+
 
 def parse_response(response):
     """Parses response and throw exception if not successful."""
